@@ -6,11 +6,11 @@ use utf8;
 use warnings;
 
 # Version.
-our $VERSION = 0.21;
+our $VERSION = 0.22;
 
 # Modules.
 use Acme::CPANAuthors::Register(
-	'CHOROBA' => 'Egon Choroba',
+	'CHOROBA' => 'E. Choroba',
 	'DANIELR' => 'Roman Daniel',
 	'DANPEDER' => 'Daniel Peder',
 	'DOUGLISH' => 'Dalibor Hořínek',
@@ -176,6 +176,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.21
+0.22
 
 =cut
